@@ -234,15 +234,15 @@ def view_csv_stringio(tasks: list[dict]) -> io.StringIO:
         {
             "date": "date",
             "invoice": "invoice",
-            "inv total": "worked_time_cumulative",
-            "duration": "worked_time_friendly",
+            "invoice total": "worked_time_cumulative",
+            "task duration": "worked_time_friendly",
             "task": "task_details_pretty",
         }
     )
 
     data = []
     for task in tasks:
-        x1 = task["date"].strftime("%a %m-%d")
+        x1 = task["date"].strftime("%a %m-%d-%y")
         x2 = task["worked_time_friendly"]
         x3 = task["worked_time"]
         x4 = task["worked_time_cumulative"]
